#
# spec file for package pkcs11-helper
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pkcs11-helper
Version:        1.25.1
Release:        1.12
Summary:        Helper Library for the Use with Smart Cards and the PKCS#11 API
License:        BSD-3-Clause AND GPL-2.0-only
Group:          Development/Libraries/C and C++
Url:            https://github.com/OpenSC/OpenSC/wiki
Source:         https://github.com/OpenSC/pkcs11-helper/releases/download/%{name}-%{version}/%{name}-%{version}.tar.bz2
Source2:        baselibs.conf
BuildRequires:  doxygen
BuildRequires:  fdupes
#BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(openssl)
Requires:       libpkcs11-helper1 = %{version}

%description
pkcs11-helper allows using multiple PKCS#11 providers at the same
time and selecting keys by id, label or certificate subject.
Besides it covers the following topics: * Handling card removal
and card insert events:
* Handling card re-insert to a different slot
* Supporting session expiration serialization
* and much more All this is possible using a simple API.

%package -n libpkcs11-helper1
Summary:        Helper Library for the Use with Smart Cards and the PKCS#11 API
Group:          System/Libraries

%description -n libpkcs11-helper1
pkcs11-helper allows using multiple PKCS#11 providers at the same time,
selecting keys by id, label or certificate subject, handling card
removal and card insert events, handling card re-insert to a different
slot, supporting session expiration serialization and much more, all
using a simple API.

%package devel
Summary:        Helper Library for the Use with Smart Cards and the PKCS#11 API
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       pkgconfig(openssl)

%description devel
pkcs11-helper allows using multiple PKCS#11 providers at the same time,
selecting keys by id, label or certificate subject, handling card
removal and card insert events, handling card re-insert to a different
slot, supporting session expiration serialization and much more, all
using a simple API.

%prep
%setup -q

%build
#autoreconf -fvi
# We use only openssl - disable all other engines
%configure \
  --disable-static \
  --enable-doc \
  --docdir=%{_docdir}/%{name} \
  --disable-crypto-engine-gnutls \
  --disable-crypto-engine-nss \
  --disable-crypto-engine-polarssl \
  --disable-crypto-engine-mbedtls \
  --disable-crypto-engine-cryptoapi
make %{?_smp_mflags}

%install
%make_install
cp -a AUTHORS ChangeLog THANKS %{buildroot}%{_docdir}/%{name}/
find %{buildroot} -type f -name "*.la" -delete -print
%fdupes %{buildroot}%{_docdir}

%post -n libpkcs11-helper1 -p /sbin/ldconfig
%postun -n libpkcs11-helper1 -p /sbin/ldconfig

%files
%doc %{_docdir}/%{name}
%exclude %{_docdir}/%{name}/api
%{_mandir}/man8/*%{ext_man}

%files -n libpkcs11-helper1
%{_libdir}/libpkcs11-helper.so.*

%files devel
%doc %{_docdir}/%{name}/api
%{_includedir}/pkcs11-helper-1.0
%{_libdir}/pkgconfig/*.pc
%{_libdir}/*.so
%{_datadir}/aclocal/*.m4

%changelog
* Tue Jan 29 2019 sbrabec@suse.com
- Update to version 1.25.1:
  * core: build with threading disabled, do not attempt to
    initialize provider with fork mode is not safe. Too many
    providers do not follow the PKCS#11 spec.
  * openssl: rework support 1.1.
* Wed Jul 19 2017 jengelh@inai.de
- RPM group fix.
- Remove --with-pic which is only for static libs.
* Tue Jul 18 2017 tchvatal@suse.com
- Version update to 1.22:
  * Support openssl-1.1
  * bunch of small fixes
- Remove obsolete patch pkcs11-helper-1.06-pkgconfig.patch
* Sat Dec 20 2014 p.drouand@gmail.com
- Update to version 1.11
  + openssl: support generic pkey.
  + openssl: add dsa support.
  + openssl: add ecdsa support.
- Changes from version 1.10
  + PolarSSL crypto engine by Adriaan de Jong
  + build: --disable-crypto-engine-win32 renamed to
  - -disable-crypto-engine-cryptoapi
  + api: PKCS11H_FEATURE_MASK_ENGINE_CRYPTO_WIN32 renamed to
    PKCS11H_FEATURE_MASK_ENGINE_CRYPTO_CRYPTOAPI.
  + api: PKCS11H_ENGINE_CRYPTO_WIN32 renamed to
    PKCS11H_ENGINE_CRYPTO_CRYPTOAPI
- pkcs11-helper has a new home; update homepage and source Url
* Sat Mar  2 2013 coolo@suse.com
- update license to new format
* Tue Jul 10 2012 sbrabec@suse.cz
- Update to version 1.09:
  * Do not retry if CKR_BUFFER_TOO_SMALL and none NULL target.
  * Do not attempt to logout if uninitialized.
  * Use OpenSSL engine's rsa_priv_enc instead of rsa_sign.
* Sun Nov 20 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Mon Feb  1 2010 jengelh@medozas.de
- package baselibs.conf
* Thu Apr  9 2009 sbrabec@suse.cz
- Updated to version 1.07:
  * Minor portability fix.
- Don't call autoreconf on older products.
* Thu Mar 19 2009 crrodriguez@suse.de
- remove static libraries and "la" files
- fix -devel package dependencies and pkgconfig file
* Mon Sep  8 2008 sbrabec@suse.cz
- Updated to version 1.06:
  * Portability fixes.
* Tue Apr 15 2008 ro@suse.de
- added baselibs.conf file for multilib support
* Wed Apr  2 2008 sbrabec@suse.cz
- Updated to version 1.05:
  * Export pkcs11h_logout().
  * Added NSS crypto engine.
  * Added new slotevent mode (poll vs fetch).
  * Add more invalid characters to serialization string.
  * Fix openssl decrypt return code.
* Wed Aug  8 2007 sbrabec@suse.cz
- Fixed dependencies to allow to install more instances of library.
* Wed Aug  1 2007 sbrabec@suse.cz
- New SuSE package, version 1.03.
